# Copyright 2019 Red Hat, Inc.
# All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

from oslo_config import cfg


whitebox_neutron_plugin_options = cfg.OptGroup(
    name="whitebox_neutron_plugin_options",
    title="Whitebox neutron tempest plugin config options"
)

WhiteboxNeutronPluginOptions = [
    cfg.StrOpt('openstack_type',
               default='devstack',
               help='Type of openstack deployment, '
               'e.g. devstack, podified'),
    cfg.StrOpt('pki_private_key',
               default='/etc/pki/tls/private/ovn_controller.key',
               help='File with private key. Need for TLS-everywhere '
                    'environments.'),
    cfg.StrOpt('pki_certificate',
               default='/etc/pki/tls/certs/ovn_controller.crt',
               help='File with certificate for private key. Need for '
                    'TLS-everywhere environments.'),
    cfg.StrOpt('pki_ca_cert',
               default='/etc/ipa/ca.crt',
               help='File with peer CA certificate. Need for TLS-everywhere '
                    'environments.'),
    cfg.StrOpt('default_instance_interface',
               default='eth0',
               help='Default first interface name used in VM instances'
                    'Typical values are eth0, ens5, etc'),
    cfg.IntOpt('mcast_groups_count',
               default=1,
               help='How many groups to use in multicast tests. Default value '
                    'of 1 is for environments with low resources. '
                    'Recommended value is 2.'),
    cfg.IntOpt('mcast_receivers_count',
               default=1,
               help='How many receivers to use in multicast tests. Default '
                    'value of 1 is for environments with low resources. '
                    'Recommended value is 2.'),
    cfg.IntOpt('external_igmp_querier_period',
               default=170,
               help='Time in seconds external igmp querier is sending its '
                    'periodical queries'),
    cfg.BoolOpt('run_traffic_flow_tests',
                default=False,
                help='Specify explicitly whether to run traffic flow tests.'
                     ' This is needed because some ML2 plugins (e.g. ovn ) do '
                     'not expose api_extensions like dvr for some purposes.'),
    cfg.IntOpt('broadcast_receivers_count',
               default=2,
               help='How many receivers to use in broadcast tests. Default '
                    'and recommended value of 2. In case of environments '
                    'with low resources, set it to 1.'),
    cfg.BoolOpt('bgp',
                default=False,
                help='Specifies whether the OSP setup under test has been '
                     'configured with BGP functionality or not'),
    cfg.IntOpt('sriov_pfs_per_host',
               default=1,
               help='Number of available PF (Physical Function) ports per'
                    'compute node on the environment under test'),
    cfg.IntOpt('sriov_vfs_per_pf',
               default=5,
               help='Number of available VF (Virtual Function) ports per'
                    'PF interface on the environment under test'),
    cfg.StrOpt('overcloud_ssh_user',
               default='zuul',
               help='Common user to access openstack nodes via ssh.'),
    cfg.StrOpt('overcloud_key_file',
               default='/home/tempest/.ssh/id_rsa',
               help='ssh private key file path for overcloud nodes access.'),
    cfg.StrOpt('neutron_config',
               default='/etc/neutron/neutron.conf',
               help='Path to neutron configuration file.'),
    cfg.IntOpt('ovn_max_controller_gw_ports_per_router',
               default=1,
               help='The number of network nodes used '
                    'for the OVN router HA.')
]
